==> grafana-enterprise-10.4.19.linux-arm64.tar.gz: grafana-v10.4.19/docs/sources/whatsnew/_index.md <==
---
aliases:
  - guides/
  - guides/whats-new-in-v2-1/
  - guides/whats-new-in-v2-5/
  - guides/whats-new-in-v2-6/
  - guides/whats-new-in-v2/
  - guides/whats-new-in-v3-1/
  - guides/whats-new-in-v3/
  - guides/whats-new-in-v4-1/
  - guides/whats-new-in-v4-2/
  - guides/whats-new-in-v4-3/
  - guides/whats-new-in-v4-4/
  - guides/whats-new-in-v4-5/
  - guides/whats-new-in-v4-6/
  - guides/whats-new-in-v4/
  - guides/whats-new-in-v5-1/
  - guides/whats-new-in-v5-2/
  - guides/whats-new-in-v5-3/
  - guides/whats-new-in-v5-4/
  - guides/whats-new-in-v5/
  - guides/whats-new-in-v6-0/
  - guides/whats-new-in-v6-1/
  - guides/whats-new-in-v6-2/
  - guides/whats-new-in-v6-3/
  - guides/whats-new-in-v6-4/
  - guides/whats-new-in-v6-5/
  - guides/whats-new-in-v6-6/
  - guides/whats-new-in-v6-7/
  - whats-new-in-v2-0/
  - whats-new-in-v2-1/
  - whats-new-in-v2-5/
  - whats-new-in-v2-6/
  - whats-new-in-v3-0/
  - whats-new-in-v3-1/
  - whats-new-in-v4-0/
  - whats-new-in-v4-1/
  - whats-new-in-v4-2/
  - whats-new-in-v4-3/
  - whats-new-in-v4-4/
  - whats-new-in-v4-5/
  - whats-new-in-v4-6/
  - whats-new-in-v5-0/
  - whats-new-in-v5-1/
  - whats-new-in-v5-2/
  - whats-new-in-v5-3/
  - whats-new-in-v5-4/
  - whats-new-in-v6-0/
  - whats-new-in-v6-1/
  - whats-new-in-v6-2/
  - whats-new-in-v6-3/
  - whats-new-in-v6-4/
  - whats-new-in-v6-5/
  - whats-new-in-v6-6/
  - whats-new-in-v6-7/
description: Learn about new and updated features in Grafana.
labels:
  products:
    - cloud
    - enterprise
    - oss
menuTitle: What's new
title: What's new in Grafana
weight: 1
---

# What's new in Grafana

For release highlights, deprecations, and breaking changes in Grafana releases, refer to these "What's new" pages for each version.

{{% admonition type="note" %}}
For Grafana versions prior to v9.2, additional information might also be available in the archive of [release notes](../release-notes/).
{{% /admonition %}}

For a complete list of every change, with links to pull requests and related issues when available, see the [Changelog](https://github.com/grafana/grafana/blob/main/CHANGELOG.md).

## Grafana 11

- [What's new in 11.0-preview](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v11-0/)

## Grafana 10

- [What's new in 10.4](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v10-4/)
- [What's new in 10.3](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v10-3/)
- [What's new in 10.2](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v10-2/)
- [What's new in 10.1](whats-new-in-v10-1/)
- [What's new in 10.0](whats-new-in-v10-0/)

## Grafana 9

- [What's new in 9.5](whats-new-in-v9-5/)
- [What's new in 9.4](whats-new-in-v9-4/)
- [What's new in 9.3](whats-new-in-v9-3/)
- [What's new in 9.2](whats-new-in-v9-2/)
- [What's new in 9.1](whats-new-in-v9-1/)
- [What's new in 9.0](whats-new-in-v9-0/)

## Grafana 8

- [What's new in 8.5](whats-new-in-v8-5/)
- [What's new in 8.4](whats-new-in-v8-4/)
- [What's new in 8.3](whats-new-in-v8-3/)
- [What's new in 8.2](whats-new-in-v8-2/)
- [What's new in 8.1](whats-new-in-v8-1/)
- [What's new in 8.0](whats-new-in-v8-0/)

==> grafana-enterprise-11.0.9.linux-arm64.tar.gz: grafana-v11.0.9/docs/sources/whatsnew/_index.md <==
---
aliases:
  - guides/
  - guides/whats-new-in-v2-1/
  - guides/whats-new-in-v2-5/
  - guides/whats-new-in-v2-6/
  - guides/whats-new-in-v2/
  - guides/whats-new-in-v3-1/
  - guides/whats-new-in-v3/
  - guides/whats-new-in-v4-1/
  - guides/whats-new-in-v4-2/
  - guides/whats-new-in-v4-3/
  - guides/whats-new-in-v4-4/
  - guides/whats-new-in-v4-5/
  - guides/whats-new-in-v4-6/
  - guides/whats-new-in-v4/
  - guides/whats-new-in-v5-1/
  - guides/whats-new-in-v5-2/
  - guides/whats-new-in-v5-3/
  - guides/whats-new-in-v5-4/
  - guides/whats-new-in-v5/
  - guides/whats-new-in-v6-0/
  - guides/whats-new-in-v6-1/
  - guides/whats-new-in-v6-2/
  - guides/whats-new-in-v6-3/
  - guides/whats-new-in-v6-4/
  - guides/whats-new-in-v6-5/
  - guides/whats-new-in-v6-6/
  - guides/whats-new-in-v6-7/
  - whats-new-in-v2-0/
  - whats-new-in-v2-1/
  - whats-new-in-v2-5/
  - whats-new-in-v2-6/
  - whats-new-in-v3-0/
  - whats-new-in-v3-1/
  - whats-new-in-v4-0/
  - whats-new-in-v4-1/
  - whats-new-in-v4-2/
  - whats-new-in-v4-3/
  - whats-new-in-v4-4/
  - whats-new-in-v4-5/
  - whats-new-in-v4-6/
  - whats-new-in-v5-0/
  - whats-new-in-v5-1/
  - whats-new-in-v5-2/
  - whats-new-in-v5-3/
  - whats-new-in-v5-4/
  - whats-new-in-v6-0/
  - whats-new-in-v6-1/
  - whats-new-in-v6-2/
  - whats-new-in-v6-3/
  - whats-new-in-v6-4/
  - whats-new-in-v6-5/
  - whats-new-in-v6-6/
  - whats-new-in-v6-7/
description: Learn about new and updated features in Grafana.
labels:
  products:
    - cloud
    - enterprise
    - oss
menuTitle: What's new
title: What's new in Grafana
weight: 1
---

# What's new in Grafana

For release highlights, deprecations, and breaking changes in Grafana releases, refer to these "What's new" pages for each version.

{{% admonition type="note" %}}
For Grafana versions prior to v9.2, additional information might also be available in the archive of [release notes]({{< relref "../release-notes/" >}}).
{{% /admonition %}}

For a complete list of every change, with links to pull requests and related issues when available, see the [Changelog](https://github.com/grafana/grafana/blob/main/CHANGELOG.md).

## Grafana 11

- [What's new in 11.0](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v11-0/)

## Grafana 10

- [What's new in 10.4](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v10-4/)
- [What's new in 10.3](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v10-3/)
- [What's new in 10.2](https://grafana.com/docs/grafana/<GRAFANA_VERSION>/whatsnew/whats-new-in-v10-2/)
- [What's new in 10.1]({{< relref "whats-new-in-v10-1/" >}})
- [What's new in 10.0]({{< relref "whats-new-in-v10-0/" >}})

## Grafana 9

- [What's new in 9.5]({{< relref "./whats-new-in-v9-5" >}})
- [What's new in 9.4]({{< relref "./whats-new-in-v9-4" >}})
- [What's new in 9.3]({{< relref "./whats-new-in-v9-3" >}})
- [What's new in 9.2]({{< relref "./whats-new-in-v9-2" >}})
- [What's new in 9.1]({{< relref "./whats-new-in-v9-1" >}})
- [What's new in 9.0]({{< relref "./whats-new-in-v9-0" >}})

## Grafana 8

- [What's new in 8.5]({{< relref "./whats-new-in-v8-5" >}})
- [What's new in 8.4]({{< relref "./whats-new-in-v8-4" >}})
- [What's new in 8.3]({{< relref "./whats-new-in-v8-3" >}})
- [What's new in 8.2]({{< relref "./whats-new-in-v8-2" >}})
- [What's new in 8.1]({{< relref "./whats-new-in-v8-1" >}})
- [What's new in 8.0]({{< relref "./whats-new-in-v8-0" >}})
